@@ -1,16 +1,16 @@
-
 # inline execution evaluator
 inline_evaluator <- function(expr, timelimit, ...) {
-
   result <- NULL
 
   list(
     start = function() {
-
       # setTimeLimit -- if the timelimit is exceeeded an error will occur
       # during knit which we will catch and format within evaluate_exercise
-      setTimeLimit(elapsed=timelimit, transient=TRUE);
-      on.exit(setTimeLimit(cpu=Inf, elapsed=Inf, transient=FALSE), add = TRUE);
+      setTimeLimit(elapsed = timelimit, transient = TRUE)
+      on.exit(
+        setTimeLimit(cpu = Inf, elapsed = Inf, transient = FALSE),
+        add = TRUE
+      )
 
       # execute and capture result
       result <<- tryCatch(
@@ -34,7 +34,7 @@ inline_evaluator <- function(expr, timelimit, ...) {
 }
 
 # forked execution evaluator
-setup_forked_evaluator_factory <- function(max_forked_procs){
+setup_forked_evaluator_factory <- function(max_forked_procs) {
   running_exercises <- 0
 
   function(expr, timelimit, ...) {
@@ -63,11 +63,10 @@ setup_forked_evaluator_factory <- function(max_forked_procs){
     }
 
     list(
-
       start = function() {
         self$start_time <<- Sys.time()
 
-        doStart <- function(){
+        doStart <- function() {
           if (running_exercises >= max_forked_procs) {
             # Then we can't start this job yet.
             print("Delaying exercise execution due to forked proc limits")
@@ -79,7 +78,6 @@ setup_forked_evaluator_factory <- function(max_forked_procs){
           running_exercises <<- running_exercises + 1
 
           self$job <<- parallel::mcparallel(mc.interactive = FALSE, {
-
             # close all connections
             closeAllConnections()
 
@@ -105,7 +103,11 @@ setup_forked_evaluator_factory <- function(max_forked_procs){
         }
 
         # attempt to collect the result
-        collect <- parallel::mccollect(jobs = self$job, wait = FALSE, timeout = 0.01)
+        collect <- parallel::mccollect(
+          jobs = self$job,
+          wait = FALSE,
+          timeout = 0.01
+        )
 
         # got result
         if (!is.null(collect)) {
@@ -120,15 +122,19 @@ setup_forked_evaluator_factory <- function(max_forked_procs){
 
           # check if it's an error and convert it to an html error if it is
           if (inherits(self$result, "try-error")) {
-            self$result <<- exercise_result_error(self$result, timeout_exceeded = FALSE)
+            self$result <<- exercise_result_error(
+              self$result,
+              timeout_exceeded = FALSE
+            )
           }
 
           return(TRUE)
         }
 
         # hit timeout
-        if (difftime(Sys.time(), self$start_time, units="secs") >= timelimit) {
-
+        if (
+          difftime(Sys.time(), self$start_time, units = "secs") >= timelimit
+        ) {
           # call cleanup hook
           call_hook("oncleanup", default = default_cleanup)
 
@@ -151,7 +157,12 @@ setup_forked_evaluator_factory <- function(max_forked_procs){
   }
 }
 
-forked_evaluator_factory <- setup_forked_evaluator_factory(max_forked_procs = getOption("tutorial.max.forked.procs", Sys.getenv("TUTORIAL_MAX_FORKED_PROCS", 3)))
+forked_evaluator_factory <- setup_forked_evaluator_factory(
+  max_forked_procs = getOption(
+    "tutorial.max.forked.procs",
+    Sys.getenv("TUTORIAL_MAX_FORKED_PROCS", 3)
+  )
+)
 # Maintain for backwards-compatibility with original implementation in which
 # forked_evaluator was uncapped
 forked_evaluator <- setup_forked_evaluator_factory(max_forked_procs = Inf)
@@ -168,9 +179,12 @@ forked_evaluator <- setup_forked_evaluator_factory(max_forked_procs = Inf)
 #'   and `session`.
 #' @export
 external_evaluator <- function(
-  endpoint = getOption("tutorial.external.host", Sys.getenv("TUTORIAL_EXTERNAL_EVALUATOR_HOST", NA)),
+  endpoint = getOption(
+    "tutorial.external.host",
+    Sys.getenv("TUTORIAL_EXTERNAL_EVALUATOR_HOST", NA)
+  ),
   max_curl_conns = 50
-){
+) {
   rlang::check_installed("curl", "to use an external evaluator.")
   internal_external_evaluator(endpoint, max_curl_conns)
 }
@@ -186,10 +200,12 @@ external_evaluator <- function(
 internal_external_evaluator <- function(
   endpoint,
   max_curl_conns,
-  initiate = initiate_external_session){
-
-  if (is.na(endpoint)){
-    stop("You must specify an endpoint explicitly as a parameter, or via the `tutorial.external.host` option, or the `TUTORIAL_EXTERNAL_EVALUATOR_HOST` environment variable")
+  initiate = initiate_external_session
+) {
+  if (is.na(endpoint)) {
+    stop(
+      "You must specify an endpoint explicitly as a parameter, or via the `tutorial.external.host` option, or the `TUTORIAL_EXTERNAL_EVALUATOR_HOST` environment variable"
+    )
   }
 
   # Trim trailing slash
@@ -197,38 +213,61 @@ internal_external_evaluator <- function(
 
   function(expr, timelimit, exercise, session, ...) {
     result <- NULL
-    pool <- curl::new_pool(total_con = max_curl_conns, host_con = max_curl_conns)
+    pool <- curl::new_pool(
+      total_con = max_curl_conns,
+      host_con = max_curl_conns
+    )
 
     list(
       start = function() {
-
         # The actual workhorse here -- called once we have a session ID on the external evaluator
-        submit_req <- function(sess_id, cookiejar){
+        submit_req <- function(sess_id, cookiejar) {
           # Work around a few edge cases on the exercise that don't serialize well
-          if (identical(exercise$options$exercise.checker, "NULL")){
+          if (identical(exercise$options$exercise.checker, "NULL")) {
             exercise$options$exercise.checker <- c()
           }
 
-          json <- jsonlite::toJSON(exercise, auto_unbox = TRUE, null = "null", force = TRUE)
+          json <- jsonlite::toJSON(
+            exercise,
+            auto_unbox = TRUE,
+            null = "null",
+            force = TRUE
+          )
           if (
-            identical(tolower(Sys.getenv("TUTORIAL_DEBUG_EXTERNAL_EVALUATOR_EVENT_SUBMISSION", "")), "true") ||
-            "submission" %in% getOption("tutorial.debug.external_evaluator_event", "")
+            identical(
+              tolower(Sys.getenv(
+                "TUTORIAL_DEBUG_EXTERNAL_EVALUATOR_EVENT_SUBMISSION",
+                ""
+              )),
+              "true"
+            ) ||
+              "submission" %in%
+                getOption("tutorial.debug.external_evaluator_event", "")
           ) {
-            event_trigger(session, "external_evaluator_submission", as.character(json))
+            event_trigger(
+              session,
+              "external_evaluator_submission",
+              as.character(json)
+            )
           }
 
-          if (is.null(exercise$options$exercise.timelimit) || exercise$options$exercise.timelimit == 0){
+          if (
+            is.null(exercise$options$exercise.timelimit) ||
+              exercise$options$exercise.timelimit == 0
+          ) {
             timeout_s <- 30 * 1000
           } else {
             timeout_s <- exercise$options$exercise.timelimit * 1000
           }
 
           # Create curl request
-          handle <- curl::new_handle(customrequest = "POST",
-                                     copypostfields = json,
-                                     # add 15 seconds for application startup
-                                     timeout_ms = timeout_s + 15000,
-                                     cookiefile=cookiejar)
+          handle <- curl::new_handle(
+            customrequest = "POST",
+            copypostfields = json,
+            # add 15 seconds for application startup
+            timeout_ms = timeout_s + 15000,
+            cookiefile = cookiejar
+          )
           curl::handle_setheaders(handle, "Content-Type" = "application/json")
 
           url <- paste0(endpoint, "/learnr/", sess_id)
@@ -238,48 +277,66 @@ internal_external_evaluator <- function(
           # requests in the pool to resolve.
           pending <- TRUE
 
-          done_cb <- function(res){
+          done_cb <- function(res) {
             pending <<- FALSE
 
-            tryCatch({
-              if (res$status != 200){
+            tryCatch(
+              {
+                if (res$status != 200) {
+                  fail_cb(response_to_error(res))
+                  return()
+                }
+
+                r <- rawToChar(res$content)
+                if (
+                  identical(
+                    tolower(Sys.getenv(
+                      "TUTORIAL_DEBUG_EXTERNAL_EVALUATOR_EVENT_RESULT",
+                      ""
+                    )),
+                    "true"
+                  ) ||
+                    "result" %in%
+                      getOption("tutorial.debug.external_evaluator_event", "")
+                ) {
+                  event_trigger(session, "external_evaluator_result", r)
+                }
+
+                valid_json <- jsonlite::validate(r)
+                if (!valid_json) {
+                  stop(attr(valid_json, "err"))
+                }
+
+                result <<- r
+              },
+              error = function(e) {
+                print(e)
                 fail_cb(response_to_error(res))
-                return()
               }
-
-              r <- rawToChar(res$content)
-              if (
-                identical(tolower(Sys.getenv("TUTORIAL_DEBUG_EXTERNAL_EVALUATOR_EVENT_RESULT", "")), "true") ||
-                "result" %in% getOption("tutorial.debug.external_evaluator_event", "")
-              ) {
-                event_trigger(session, "external_evaluator_result", r)
-              }
-
-              valid_json <- jsonlite::validate(r)
-              if (!valid_json) {
-                stop(attr(valid_json, "err"))
-              }
-
-              result <<- r
-            }, error = function(e){
-              print(e)
-              fail_cb(response_to_error(res))
-            })
+            )
           }
 
-          fail_cb <- function(err){
+          fail_cb <- function(err) {
             pending <<- FALSE
 
             print("Error submitting external exercise:")
             print(err)
-            result <<- exercise_result_error("Error submitting external exercise. Please try again later")
+            result <<- exercise_result_error(
+              "Error submitting external exercise. Please try again later"
+            )
           }
 
-          curl::curl_fetch_multi(url, handle = handle, done = done_cb, fail = fail_cb, pool = pool)
+          curl::curl_fetch_multi(
+            url,
+            handle = handle,
+            done = done_cb,
+            fail = fail_cb,
+            pool = pool
+          )
 
-          poll <- function(){
+          poll <- function() {
             curl::multi_run(timeout = 0, pool = pool)
-            if (pending){
+            if (pending) {
               later::later(poll, delay = 0.1)
             }
           }
@@ -287,11 +344,15 @@ internal_external_evaluator <- function(
         }
 
         # Initiate a session
-        if (is.null(session$userData$.external_evaluator_session_id)){
+        if (is.null(session$userData$.external_evaluator_session_id)) {
           session$userData$.external_evaluator_session_id <-
-            initiate(pool, paste0(endpoint, "/learnr/"), exercise$global_setup) %>%
-            then(onFulfilled = function(extsess){
-              session$onSessionEnded(function(){
+            initiate(
+              pool,
+              paste0(endpoint, "/learnr/"),
+              exercise$global_setup
+            ) %>%
+            then(onFulfilled = function(extsess) {
+              session$onSessionEnded(function() {
                 # Cleanup session cookiefile
                 # Because of https://github.com/rstudio/shiny/pull/2757, we can't
                 # trust that the reactive context will be provided here. So just
@@ -302,15 +363,18 @@ internal_external_evaluator <- function(
             })
         }
 
-        session$userData$.external_evaluator_session_id %>% then(
-          onFulfilled = function(extsess){
-            submit_req(extsess$id, extsess$cookieFile)
-          },
-          onRejected = function(err){
-            print(err)
-            result <<- exercise_result_error("Error initiating session for external requests. Please try again later")
-          }
-        )
+        session$userData$.external_evaluator_session_id %>%
+          then(
+            onFulfilled = function(extsess) {
+              submit_req(extsess$id, extsess$cookieFile)
+            },
+            onRejected = function(err) {
+              print(err)
+              result <<- exercise_result_error(
+                "Error initiating session for external requests. Please try again later"
+              )
+            }
+          )
       },
 
       completed = function() {
@@ -321,18 +385,21 @@ internal_external_evaluator <- function(
         if (is_exercise_result(result)) {
           return(result)
         }
-        tryCatch({
-          if (length(result) > 1) {
-            result <- paste(result, collapse = "\n")
+        tryCatch(
+          {
+            if (length(result) > 1) {
+              result <- paste(result, collapse = "\n")
+            }
+            exercise_result_from_json(result)
+          },
+          error = function(e) {
+            exercise_result_error_internal(
+              exercise = exercise,
+              error = e,
+              task_internal = "converting result from external evaluator into a learnr exercise result"
+            )
           }
-          exercise_result_from_json(result)
-        }, error = function(e) {
-          exercise_result_error_internal(
-            exercise = exercise,
-            error = e,
-            task_internal = "converting result from external evaluator into a learnr exercise result"
-          )
-        })
+        )
       }
     )
   }
@@ -385,23 +452,37 @@ exercise_result_from_json <- function(json) {
 #' @importFrom promises promise
 #' @importFrom promises %>%
 #' @noRd
-initiate_external_session <- function(pool, url, global_setup, retry_count = 0){
-  promises::promise(function(resolve, reject){
-    json <- jsonlite::toJSON(list(global_setup = global_setup), auto_unbox = TRUE, null = "null")
-    handle <- curl::new_handle(customrequest = "POST",
-                               copypostfields = json)
+initiate_external_session <- function(
+  pool,
+  url,
+  global_setup,
+  retry_count = 0
+) {
+  promises::promise(function(resolve, reject) {
+    json <- jsonlite::toJSON(
+      list(global_setup = global_setup),
+      auto_unbox = TRUE,
+      null = "null"
+    )
+    handle <- curl::new_handle(customrequest = "POST", copypostfields = json)
 
     # Track whether or not the current request is still active.
     # We cannot use multi_run()$pending because it waits for ALL pending
     # requests in the pool to resolve.
     pending <- TRUE
 
-    err_cb <- function(res){
+    err_cb <- function(res) {
       pending <<- FALSE
 
       # may just have hit a temporarily overloaded server. Retry
-      if (res$status == 503 && retry_count < 2) { # three total tries
-        resolve(initiate_external_session(pool, url, global_setup, retry_count+1))
+      if (res$status == 503 && retry_count < 2) {
+        # three total tries
+        resolve(initiate_external_session(
+          pool,
+          url,
+          global_setup,
+          retry_count + 1
+        ))
         return()
       } else {
         # invoke the given error callback
@@ -410,26 +491,29 @@ initiate_external_session <- function(pool, url, global_setup, retry_count = 0){
       }
     }
 
-    done_cb <- function(res){
+    done_cb <- function(res) {
       pending <<- FALSE
 
       id <- NULL
       failed <- FALSE
 
-      if (res$status != 200){
+      if (res$status != 200) {
         reject(response_to_error(res))
         return()
       }
 
-      tryCatch({
-        r <- rawToChar(res$content)
-        p <- jsonlite::fromJSON(r)
-        id <- p$id
-      }, error = function(e) {
-        print(e)
-        reject(response_to_error(res))
-        return()
-      })
+      tryCatch(
+        {
+          r <- rawToChar(res$content)
+          p <- jsonlite::fromJSON(r)
+          id <- p$id
+        },
+        error = function(e) {
+          print(e)
+          reject(response_to_error(res))
+          return()
+        }
+      )
 
       cookies <- curl::handle_cookies(handle)
       cookieFile <- tempfile("cookies")
@@ -437,11 +521,17 @@ initiate_external_session <- function(pool, url, global_setup, retry_count = 0){
       resolve(list(id = id, cookieFile = cookieFile))
     }
 
-    curl::curl_fetch_multi(url, handle = handle, done = done_cb, fail = reject, pool = pool)
+    curl::curl_fetch_multi(
+      url,
+      handle = handle,
+      done = done_cb,
+      fail = reject,
+      pool = pool
+    )
 
-    poll <- function(){
+    poll <- function() {
       curl::multi_run(timeout = 0, pool = pool)
-      if (pending){
+      if (pending) {
         later::later(poll, delay = 0.1)
       }
     }
@@ -449,14 +539,14 @@ initiate_external_session <- function(pool, url, global_setup, retry_count = 0){
   })
 }
 
-response_to_error <- function(res){
+response_to_error <- function(res) {
   headers <- res$headers
-  if (is.raw(headers)){
+  if (is.raw(headers)) {
     headers <- rawToChar(headers)
   }
 
   content <- res$content
-  if (is.raw(content)){
+  if (is.raw(content)) {
     content <- rawToChar(content)
   }
 
@@ -484,9 +574,18 @@ response_to_error <- function(res){
 # So we settled on this approach -- persisting the cookies off the connection
 # ourselves in a format that can be read in by curl using the COOKIEFILE option.
 #' @importFrom utils write.table
-write_cookies <- function(cookies, cookieFile){
+write_cookies <- function(cookies, cookieFile) {
   cookies$expiration <- as.numeric(cookies$expiration)
-  cookies$expiration[is.infinite(cookies$expiration) | is.na(cookies$expiration)] <- 0
+  cookies$expiration[
+    is.infinite(cookies$expiration) | is.na(cookies$expiration)
+  ] <- 0
   cookies$expiration <- as.integer(cookies$expiration)
-  write.table(cookies, cookieFile, row.names=FALSE, col.names=FALSE, sep="\t", quote = FALSE)
+  write.table(
+    cookies,
+    cookieFile,
+    row.names = FALSE,
+    col.names = FALSE,
+    sep = "\t",
+    quote = FALSE
+  )
 }
