@@ -1,6 +1,3 @@
-
-
-
 #' Initialize tutorial R Markdown extensions
 #'
 #' One time initialization of R Markdown extensions required by the
@@ -12,11 +9,11 @@
 #'
 #' @export
 initialize_tutorial <- function() {
-
   # helper function for one time initialization
-  if (isTRUE(getOption("knitr.in.progress")) &&
-      !isTRUE(knitr::opts_knit$get("tutorial.initialized"))) {
-
+  if (
+    isTRUE(getOption("knitr.in.progress")) &&
+      !isTRUE(knitr::opts_knit$get("tutorial.initialized"))
+  ) {
     # html dependencies
     knitr::knit_meta_add(list(
       rmarkdown::html_dependency_jquery(),
@@ -29,8 +26,10 @@ initialize_tutorial <- function() {
     # session initialization (forward tutorial metadata)
     rmarkdown::shiny_prerendered_chunk(
       'server',
-      sprintf('learnr:::register_http_handlers(session, metadata = %s)',
-              dput_to_string(rmarkdown::metadata$tutorial)),
+      sprintf(
+        'learnr:::register_http_handlers(session, metadata = %s)',
+        dput_to_string(rmarkdown::metadata$tutorial)
+      ),
       singleton = TRUE
     )
 
@@ -50,9 +49,11 @@ initialize_tutorial <- function() {
     # Register session stop handler
     rmarkdown::shiny_prerendered_chunk(
       'server',
-      sprintf('session$onSessionEnded(function() {
+      sprintf(
+        'session$onSessionEnded(function() {
         learnr:::event_trigger(session, "session_stop")
-      })'),
+      })'
+      ),
       singleton = TRUE
     )
 
@@ -64,7 +65,9 @@ initialize_tutorial <- function() {
 
 dput_to_string <- function(x) {
   conn <- textConnection("dput_to_string", "w")
-  on.exit({close(conn)})
+  on.exit({
+    close(conn)
+  })
   dput(x, file = conn)
   # Must use a `"\n"` if `dput()`ing a function
   paste0(textConnectionValue(conn), collapse = "\n")
