@@ -23,12 +23,18 @@
 #' )
 #' cat(format(ex_question), "\n")
 format.tutorial_question_answer <- function(x, ..., spacing = "") {
-  correct_label <- if (is.null(x$correct)) "?" else ifelse(x$correct, "\u2714", "X")
+  correct_label <- if (is.null(x$correct)) {
+    "?"
+  } else {
+    ifelse(x$correct, "\u2714", "X")
+  }
   paste0(
     spacing,
     correct_label,
     ": ",
-    "\"", x$label, "\"",
+    "\"",
+    x$label,
+    "\"",
     if (!is.null(x$message)) paste0("; \"", x$message, "\"")
   )
 }
@@ -46,29 +52,68 @@ format.tutorial_question <- function(x, ..., spacing = "") {
     if (length(x$options) > 0) {
       paste0(
         "\n",
-        spacing, "  Options:\n",
-        paste0(mapply(SIMPLIFY = FALSE, names(x$options), x$options, FUN = function(name, val) {
-          paste0(spacing, "    ", name, ": ", quote_chars(val))
-        }), collapse = "\n")
+        spacing,
+        "  Options:\n",
+        paste0(
+          mapply(
+            SIMPLIFY = FALSE,
+            names(x$options),
+            x$options,
+            FUN = function(name, val) {
+              paste0(spacing, "    ", name, ": ", quote_chars(val))
+            }
+          ),
+          collapse = "\n"
+        )
       )
     } else {
       NULL
     }
   # x$label belongs to the knitr label
   paste0(
-    spacing, "Question: \"", x$question, "\"\n",
+    spacing,
+    "Question: \"",
+    x$question,
+    "\"\n",
     # all for a type vector
-    spacing, "  type: ", paste0("\"", x$type, "\"", sep = "", collapse = ", "), "\n",
-    spacing, "  allow_retry: ", x$allow_retry, "\n",
-    spacing, "  random_answer_order: ", x$random_answer_order, "\n",
-    spacing, "  answers:\n",
-    paste0(lapply(x$answers, format, spacing = paste0(spacing, "    ")), collapse = "\n"), "\n",
-    spacing, "  messages:\n",
-    spacing, "    correct: \"", x$messages$correct, "\"\n",
-    spacing, "    incorrect: \"", x$messages$incorrect, "\"",
-    if (x$allow_retry) paste0("\n", spacing, "    try_again: \"", x$messages$try_again, "\""),
-    if (!is.null(x$messages$message)) paste0("\n", spacing, "    message: \"", x$messages$message, "\""),
-    if (!is.null(x$messages$post_message)) paste0("\n", spacing, "    message: \"", x$messages$post_message, "\""),
+    spacing,
+    "  type: ",
+    paste0("\"", x$type, "\"", sep = "", collapse = ", "),
+    "\n",
+    spacing,
+    "  allow_retry: ",
+    x$allow_retry,
+    "\n",
+    spacing,
+    "  random_answer_order: ",
+    x$random_answer_order,
+    "\n",
+    spacing,
+    "  answers:\n",
+    paste0(
+      lapply(x$answers, format, spacing = paste0(spacing, "    ")),
+      collapse = "\n"
+    ),
+    "\n",
+    spacing,
+    "  messages:\n",
+    spacing,
+    "    correct: \"",
+    x$messages$correct,
+    "\"\n",
+    spacing,
+    "    incorrect: \"",
+    x$messages$incorrect,
+    "\"",
+    if (x$allow_retry) {
+      paste0("\n", spacing, "    try_again: \"", x$messages$try_again, "\"")
+    },
+    if (!is.null(x$messages$message)) {
+      paste0("\n", spacing, "    message: \"", x$messages$message, "\"")
+    },
+    if (!is.null(x$messages$post_message)) {
+      paste0("\n", spacing, "    message: \"", x$messages$post_message, "\"")
+    },
     options
   )
 }
@@ -76,7 +121,9 @@ format.tutorial_question <- function(x, ..., spacing = "") {
 #' @rdname format_quiz
 format.tutorial_quiz <- function(x, ...) {
   paste0(
-    "Quiz: \"", x$caption, "\"\n",
+    "Quiz: \"",
+    x$caption,
+    "\"\n",
     "\n",
     paste0(lapply(x$questions, format, spacing = "  "), collapse = "\n\n")
   )
