@@ -1,10 +1,16 @@
 test_that("forked_evaluator works as expected", {
   skip_on_cran()
-  skip_if(is_windows(), message = "Skipping forked evaluator testing on Windows")
+  skip_if(
+    is_windows(),
+    message = "Skipping forked evaluator testing on Windows"
+  )
   skip_if(is_mac(), message = "Skipping forked evaluator testing on macOS")
 
   ex <- mock_exercise("Sys.sleep(1)\n1:100", check = I("last_value"))
-  forked_eval_ex <- forked_evaluator_factory(evaluate_exercise(ex, new.env()), 2)
+  forked_eval_ex <- forked_evaluator_factory(
+    evaluate_exercise(ex, new.env()),
+    2
+  )
 
   # not yet started
   expect_equal(forked_eval_ex$completed(), NA)
@@ -34,9 +40,9 @@ pool <- curl::new_pool(total_con = 5, host_con = 5)
 #  skip these tests which makes that more complicated.
 # @param responses - a list indexed by `<verb> <path>` which maps to an httpuv
 #   response. e.g. list(`GET /` = list(status = 200L, headers = list(), body = "OK"))
-start_server <- function(responses, quiet = TRUE){
+start_server <- function(responses, quiet = TRUE) {
   srv <- NULL
-  result <- new.env(parent=emptyenv())
+  result <- new.env(parent = emptyenv())
   result$reqs <- NULL
 
   result$port <- httpuv::randomPort()
@@ -45,7 +51,7 @@ start_server <- function(responses, quiet = TRUE){
     cat("Starting server on port", result$port, "\n")
   }
 
-  req_to_id <- function(req){
+  req_to_id <- function(req) {
     paste(req$REQUEST_METHOD, req$PATH_INFO)
   }
 
@@ -56,15 +62,14 @@ start_server <- function(responses, quiet = TRUE){
     quiet = quiet,
     app = list(
       call = function(req) {
-
         body <- req$rook.input$read()
-        result$reqs[[ length(result$reqs) + 1 ]] <<- list(req = req, body=body)
+        result$reqs[[length(result$reqs) + 1]] <<- list(req = req, body = body)
 
         # See if this method + path has a defined response
         id <- req_to_id(req)
-        if (!is.null(responses[[id]])){
+        if (!is.null(responses[[id]])) {
           res <- responses[[id]]
-          if (is.function(res)){
+          if (is.function(res)) {
             # Invoke
             return(res())
           } else {
@@ -91,41 +96,49 @@ start_server <- function(responses, quiet = TRUE){
 test_that("initiate_external_session works", {
   testthat::skip_on_cran()
 
-  responses <- list(`POST /learnr/` = list(
-    status = 200L,
-    headers = list(
-      'Content-Type' = 'application/json'
-    ),
-    body = '{"id": "abcd1234"}'
-  ))
+  responses <- list(
+    `POST /learnr/` = list(
+      status = 200L,
+      headers = list(
+        'Content-Type' = 'application/json'
+      ),
+      body = '{"id": "abcd1234"}'
+    )
+  )
 
   srv <- start_server(responses)
   withr::defer(srv$stop())
 
   failed <- FALSE
   sess_ids <- NULL
-  cb <- function(result){
+  cb <- function(result) {
     sess_ids <<- c(sess_ids, result$id)
   }
-  err_cb <- function(res){
+  err_cb <- function(res) {
     print(res)
     testthat::fail("Unexpected error from initiate_external_session")
     failed <<- TRUE
   }
 
   # Initiate a handful of sessions all at once
-  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>% then(cb, err_cb)
-  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>% then(cb, err_cb)
-  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>% then(cb, err_cb)
+  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>%
+    then(cb, err_cb)
+  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>%
+    then(cb, err_cb)
+  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>%
+    then(cb, err_cb)
 
-  while(!failed && length(sess_ids) < 3){
+  while (!failed && length(sess_ids) < 3) {
     later::run_now()
   }
 
   expect_equal(failed, FALSE)
   expect_equal(sess_ids, rep("abcd1234", 3))
 
-  expect_equal(jsonlite::fromJSON(rawToChar(srv$reqs[[1]]$body)), list(global_setup = ""))
+  expect_equal(
+    jsonlite::fromJSON(rawToChar(srv$reqs[[1]]$body)),
+    list(global_setup = "")
+  )
 })
 
 test_that("initiate_external_session doesn't wait on all requests", {
@@ -136,22 +149,24 @@ test_that("initiate_external_session doesn't wait on all requests", {
 
   testthat::skip_on_cran()
 
-  responses <- list(`POST /learnr/` = list(
-    status = 200L,
-    headers = list(
-      'Content-Type' = 'application/json'
-    ),
-    body = '{"id": "abcd1234"}'
-  ))
+  responses <- list(
+    `POST /learnr/` = list(
+      status = 200L,
+      headers = list(
+        'Content-Type' = 'application/json'
+      ),
+      body = '{"id": "abcd1234"}'
+    )
+  )
 
   srv <- start_server(responses)
   withr::defer(srv$stop())
 
   result <- NULL
-  cb <- function(result){
+  cb <- function(result) {
     result <<- TRUE
   }
-  err_cb <- function(res){
+  err_cb <- function(res) {
     print(res)
     testthat::fail("Unexpected error from initiate_external_session")
     result <<- FALSE
@@ -160,47 +175,57 @@ test_that("initiate_external_session doesn't wait on all requests", {
   start <- Sys.time()
 
   # Trigger a slow (2s) request
-  curl::curl_fetch_multi("http://www.httpbin.org/delay/2", done = function(res){ expect_gt(difftime(Sys.time(), start, units="secs"), 2) }, pool = pool)
+  curl::curl_fetch_multi(
+    "http://www.httpbin.org/delay/2",
+    done = function(res) {
+      expect_gt(difftime(Sys.time(), start, units = "secs"), 2)
+    },
+    pool = pool
+  )
 
   # Initiate a session
-  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>% then(cb, err_cb)
+  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>%
+    then(cb, err_cb)
 
-  while(is.null(result)){
+  while (is.null(result)) {
     later::run_now()
   }
 
   expect_equal(result, TRUE)
 
   # Should return before the slow request returns
-  expect_lt(difftime(Sys.time(), start, units="secs"), 2)
+  expect_lt(difftime(Sys.time(), start, units = "secs"), 2)
 })
 
 test_that("initiate_external_session fails with bad status", {
   testthat::skip_on_cran()
 
-  responses <- list(`POST /learnr/` = list(
-    status = 500L,
-    headers = list(
-      'Content-Type' = 'application/json'
-    ),
-    body = '{"id": "abcd1234"}'
-  ))
+  responses <- list(
+    `POST /learnr/` = list(
+      status = 500L,
+      headers = list(
+        'Content-Type' = 'application/json'
+      ),
+      body = '{"id": "abcd1234"}'
+    )
+  )
 
   srv <- start_server(responses)
   withr::defer(srv$stop())
 
   done <- FALSE
-  cb <- function(sid, cookiefile){
+  cb <- function(sid, cookiefile) {
     testthat::fail("Expected failure but got success")
     done <<- TRUE
   }
-  err_cb <- function(res){
+  err_cb <- function(res) {
     done <<- TRUE
   }
 
-  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>% then(cb, err_cb)
+  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>%
+    then(cb, err_cb)
 
-  while(!done){
+  while (!done) {
     later::run_now()
   }
 
@@ -211,30 +236,33 @@ test_that("initiate_external_session fails with bad status", {
 test_that("initiate_external_session fails with invalid JSON", {
   testthat::skip_on_cran()
 
-  responses <- list(`POST /learnr/` = list(
-    status = 200L,
-    headers = list(
-      'Content-Type' = 'application/json'
-    ),
-    body = 'this is not the JSON you seek'
-  ))
+  responses <- list(
+    `POST /learnr/` = list(
+      status = 200L,
+      headers = list(
+        'Content-Type' = 'application/json'
+      ),
+      body = 'this is not the JSON you seek'
+    )
+  )
 
   srv <- start_server(responses)
   withr::defer(srv$stop())
 
   done <- FALSE
-  cb <- function(sid, cookiefile){
+  cb <- function(sid, cookiefile) {
     testthat::fail("Expected failure but got success")
     done <<- TRUE
   }
-  err_cb <- function(res){
+  err_cb <- function(res) {
     done <<- TRUE
   }
 
   expect_output({
-    initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>% then(cb, err_cb)
+    initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>%
+      then(cb, err_cb)
 
-    while(!done){
+    while (!done) {
       later::run_now()
     }
   })
@@ -243,13 +271,15 @@ test_that("initiate_external_session fails with invalid JSON", {
 test_that("initiate_external_session fails with failed curl", {
   testthat::skip_on_cran()
 
-  responses <- list(`POST /learnr/` = list(
-    status = 200L,
-    headers = list(
-      'Content-Type' = 'application/json'
-    ),
-    body = '{"id": "abcd1234"}'
-  ))
+  responses <- list(
+    `POST /learnr/` = list(
+      status = 200L,
+      headers = list(
+        'Content-Type' = 'application/json'
+      ),
+      body = '{"id": "abcd1234"}'
+    )
+  )
 
   # Start and stop the server as a way to obtain a port number that's likely
   # inactive.
@@ -257,17 +287,18 @@ test_that("initiate_external_session fails with failed curl", {
   srv$stop()
 
   done <- FALSE
-  cb <- function(sid, cookiefile){
+  cb <- function(sid, cookiefile) {
     testthat::fail("Expected failure but got success")
     done <<- TRUE
   }
-  err_cb <- function(res){
+  err_cb <- function(res) {
     done <<- TRUE
   }
 
-  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>% then(cb, err_cb)
+  initiate_external_session(pool, paste0(srv$url, "/learnr/"), "") %>%
+    then(cb, err_cb)
 
-  while(!done){
+  while (!done) {
     later::run_now()
   }
 
@@ -279,8 +310,10 @@ test_that("external_evaluator works", {
   testthat::skip_on_cran()
 
   tf <- withr::local_tempfile()
-  mock_initiate <- function(pool, url, global_setup){
-    promises::promise(function(resolve, reject){ resolve(list(id="abcd1234", cookieFile=tf)) })
+  mock_initiate <- function(pool, url, global_setup) {
+    promises::promise(function(resolve, reject) {
+      resolve(list(id = "abcd1234", cookieFile = tf))
+    })
   }
 
   mockResult <- list(html_output = "hi")
@@ -302,20 +335,32 @@ test_that("external_evaluator works", {
 
   re <- internal_external_evaluator(srv$url, 5, mock_initiate)
 
-  mockSession <- list(onSessionEnded = function(callback){})
+  mockSession <- list(onSessionEnded = function(callback) {})
 
   # Start a couple of sessions concurrently
   e <- re(NULL, 30, list(options = list(exercise.timelimit = 5)), mockSession)
   # Simulate a session that already has an evaluator ID stashed
-  e2 <- re(NULL, 30, list(options = list(exercise.timelimit = 5)),
-           list(onSessionEnded = function(callback){}, userData =
-               list(`.external_evaluator_session_id` =
-                      promises::promise(function(resolve, reject){ resolve(list(id="efgh5678", cookieFile=tf)) }))))
+  e2 <- re(
+    NULL,
+    30,
+    list(options = list(exercise.timelimit = 5)),
+    list(
+      onSessionEnded = function(callback) {},
+      userData = list(
+        `.external_evaluator_session_id` = promises::promise(function(
+          resolve,
+          reject
+        ) {
+          resolve(list(id = "efgh5678", cookieFile = tf))
+        })
+      )
+    )
+  )
 
   e$start()
   e2$start()
 
-  while(!e$completed() || !e2$completed()) {
+  while (!e$completed() || !e2$completed()) {
     later::run_now()
   }
 
@@ -337,8 +382,10 @@ test_that("external_evaluator works", {
 })
 
 test_that("external_evaluator handles initiate failures", {
-  mock_initiate <- function(pool, url, global_setup){
-    promises::promise(function(resolve, reject){ reject(list()) })
+  mock_initiate <- function(pool, url, global_setup) {
+    promises::promise(function(resolve, reject) {
+      reject(list())
+    })
   }
 
   re <- internal_external_evaluator("http://doesntmatter", 5, mock_initiate)
@@ -348,7 +395,7 @@ test_that("external_evaluator handles initiate failures", {
   expect_output({
     e$start()
 
-    while(!e$completed()) {
+    while (!e$completed()) {
       later::run_now()
     }
   })
@@ -386,18 +433,25 @@ test_that("bad statuses or invalid json are handled sanely", {
 
   ### Test with a bad status
   tf <- withr::local_tempfile()
-  mockInit <- promise(function(resolve, reject){ resolve(list(id="badstatus", cookieFile=tf)) })
-  re <- internal_external_evaluator(srv$url, 5,
-    function(pool, url, global_setup){ mockInit })
+  mockInit <- promise(function(resolve, reject) {
+    resolve(list(id = "badstatus", cookieFile = tf))
+  })
+  re <- internal_external_evaluator(
+    srv$url,
+    5,
+    function(pool, url, global_setup) {
+      mockInit
+    }
+  )
 
   # Start a session
-  mockSession <- list(onSessionEnded = function(callback){})
+  mockSession <- list(onSessionEnded = function(callback) {})
   e <- re(NULL, 30, list(options = list(exercise.timelimit = 5)), mockSession)
 
   expect_output({
     e$start()
 
-    while(!e$completed()) {
+    while (!e$completed()) {
       later::run_now()
     }
   })
@@ -407,8 +461,15 @@ test_that("bad statuses or invalid json are handled sanely", {
 
   ### Test with invalid JSON
   tf <- withr::local_tempfile()
-  re <- internal_external_evaluator(srv$url, 5,
-    function(pool, url, global_setup){ promises::promise(function(resolve, reject){ resolve(list(id="invalidjson", cookieFile=tf)) }) })
+  re <- internal_external_evaluator(
+    srv$url,
+    5,
+    function(pool, url, global_setup) {
+      promises::promise(function(resolve, reject) {
+        resolve(list(id = "invalidjson", cookieFile = tf))
+      })
+    }
+  )
 
   # Start a session
   e <- re(NULL, 30, list(options = list(exercise.timelimit = 5)), mockSession)
@@ -416,7 +477,7 @@ test_that("bad statuses or invalid json are handled sanely", {
   expect_output({
     e$start()
 
-    while(!e$completed()) {
+    while (!e$completed()) {
       later::run_now()
     }
   })
