@@ -1,4 +1,3 @@
-
 context("storage")
 
 test_that("filesystem storage can be created", {
@@ -8,8 +7,19 @@ test_that("filesystem storage can be created", {
 
 test_that("objects cna be saved into filesystem storage", {
   fs <- filesystem_storage(tempfile())
-  fs$save_object("tutorial_id", "tutorial_version", "user_id", "object_id", "data")
-  obj <- fs$get_object("tutorial_id", "tutorial_version", "user_id", "object_id")
+  fs$save_object(
+    "tutorial_id",
+    "tutorial_version",
+    "user_id",
+    "object_id",
+    "data"
+  )
+  obj <- fs$get_object(
+    "tutorial_id",
+    "tutorial_version",
+    "user_id",
+    "object_id"
+  )
   expect_equal(obj, "data")
   fs$remove_all_objects("tutorial_id", "tutorial_version", "user_id")
-})
\ No newline at end of file
+})
